package de.intevation.flys.artifacts.math.fitting;

public class Exp
extends      Function
{
    public static final Derivative DERIVATIVE =
        new Derivative("W'(Q) = a^Q*log(a)*m") {

        @Override
        public de.intevation.flys.artifacts.math.Function
            instantiate(double [] parameters)
        {
            final double m = parameters[0];
            final double a = parameters[1];

            return new de.intevation.flys.artifacts.math.Function() {
                @Override
                public double value(double Q) {
                    return Math.pow(a, Q)*Math.log(a)*m;
                }
            };
        }
    };

    public Exp() {
        super(
            "exp",
            "W(Q) = m * a^Q + b",
            new String [] { "m", "a", "b" });
    }

    @Override
    public double value(double x, double [] parameters) {
        return parameters[0]*Math.pow(parameters[1], x) + parameters[2];
    }

    @Override
    public double [] gradient(double x, double [] parameters) {
        return new double [] {
            Math.pow(parameters[1], x),
            Math.pow(parameters[1], x-1d)*x,
            1d
        };
    }

    @Override
    public Derivative getDerivative() {
        return DERIVATIVE;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
